@@ -6,7 +6,7 @@ import attr
 import anyio
 from typing import List
 
-from .event import DeviceLocated, DeviceNotFound, DeviceValue
+from .event import DeviceLocated, DeviceNotFound, DeviceValue, DeviceException
 from .error import IsDirError
 
 import logging
@@ -464,13 +464,17 @@ class Device(SubDir):
             return getattr(self, "interval_" + typ, None)
 
     async def set_polling_interval(self, typ: str, value: float = 0):
-        if value > 0:
-            self._intervals[typ] = value
+        if isinstance(typ, str):
+            styp = typ
         else:
-            self._intervals.pop(typ, None)
+            styp = "/".join(str(x) for x in typ)
+        if value > 0:
+            self._intervals[styp] = value
+        else:
+            self._intervals.pop(styp, None)
 
         if self.bus is not None:
-            if hasattr(self, "poll_" + typ):
+            if hasattr(self, "poll_" + styp):
                 await self.bus.update_poll()
             else:
                 await self._set_poll_task(typ, value)
@@ -486,13 +490,14 @@ class Device(SubDir):
             if not value:
                 return
 
-            *p, n = typ.split("/")
+            *p, n = typ.split("/") if isinstance(typ, str) else typ
             s = self
             for pp in p:
-                s = getattr(s, pp)
-            if s.__class__.__name__ == 'IdxObj':
-                self._poll[typ] = await self.service.add_task(self._poll_task_idx, s, int(n), typ, value)
-            elif hasattr(s, "get_" + n):
+                if isinstance(pp, int):
+                    s = s[pp]
+                else:
+                    s = getattr(s, pp)
+            if isinstance(n, int) or hasattr(s, "get_" + n):
                 self._poll[typ] = await self.service.add_task(self._poll_task, s, n, typ, value)
 
             else:
@@ -501,15 +506,20 @@ class Device(SubDir):
     async def _poll_task(self, s, n, typ, value):
         await anyio.sleep(value / 5)
         while True:
-            v = await getattr(s, n)
-            await self.service.push_event(DeviceValue(self, typ, v))
-            await anyio.sleep(value)
+            try:
+                if isinstance(n, int):
+                    v = await s[n]
+                else:
+                    if n == "bar":
+                        import pdb
 
-    async def _poll_task_idx(self, s, n, typ, value):
-        await anyio.sleep(value / 5)
-        while True:
-            v = await s[n]
-            await self.service.push_event(DeviceValue(self, typ, v))
+                        pdb.set_trace()
+                    v = await getattr(s, n)
+            except Exception as exc:
+                logger.exception("Reader at %s %s", self, typ)
+                await self.service.push_event(DeviceException(self, typ, exc))
+            else:
+                await self.service.push_event(DeviceValue(self, typ, v))
             await anyio.sleep(value)
 
     async def poll_alarm(self):
@@ -575,10 +585,11 @@ class TemperatureDevice(Device):
         yield "alarm"
 
     async def poll_temperature(self):
-        #t = await self.latesttemp
+        # t = await self.latesttemp
         t = await self.temperature
         await self.service.push_event(DeviceValue(self, "temperature", t))
 
+
 #   @property
 #   def temperature(self):
 #       return self.latesttemp
